<template>
  <!-- 业务管理 首页配置 -->
  <basic-container>
    <avue-crud
      ref="crud"
      :data="data"
      :option="option"
      :table-loading="loading"
      @selection-change="selectChange"
      @row-click="rowClickHandler"
      @refresh-change="handleRefresh"
    >
      <template slot="menuLeft">
        <el-button icon="el-icon-plus" plain size="small" type="primary" @click="addClickHandler">创建
        </el-button>
        <!--<el-button icon="el-icon-delete" plain size="small" type="danger" @click="delClickHandler">删除</el-button>-->
      </template>

      <template slot="menu" slot-scope="{row,index}">
        <el-button icon="el-icon-edit" plain size="small" type="text" @click="editClickHandler(row)">修改
        </el-button>
        <el-button icon="el-icon-delete" plain size="small" type="text" @click="delRowClickHandler(row)">删除
        </el-button>
      </template>
    </avue-crud>

    <!-- 新增 修改 -->
    <el-dialog
      v-dialogDrag
      :title="dialogTitle === 'add' ? '创建' : '修改'"
      :visible.sync="visible"
      append-to-body="true"
      class="avue-dialog"
      width="540px"
      @close="visibleCloseHandler"
    >
      <el-form ref="form" :model="form" :rules="rules" label-width="95px" size="small">
        <el-row>
          <el-col :span="24">
            <el-form-item label="排序：" prop="orderNum">
              <avue-input-number v-model="form.orderNum" precision="0" style="width: 100%" :min="1" controls-position=""></avue-input-number>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="显示模块：" prop="module">
              <avue-select v-model="form.module" placeholder="请选择组件" type="tree" :dic="dic"></avue-select>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="标题：" prop="title">
              <el-input v-model="form.title"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="图标：" prop="icon">
              <input-icon v-model="form.icon" placeholder="请选择图标">
              </input-icon>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="占据列数：" prop="num" tip="总列数为24">
              <avue-input-number v-model="form.num" precision="0" style="width: 150px" :max="24" :min="1" controls-position="" labelTip="总列数为24，如占满整行请输入24"></avue-input-number>
              <span style="color: #999999;font-size: 12px;"> 按24分栏，占满一行为24</span>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="高度占比：" prop="ratio">
              <avue-input-number v-model="form.ratio" precision="2" style="width: 150px" :min="0" :max="1" controls-position=""></avue-input-number>
              <span style="color: #999999;font-size: 12px;"> 占满显示区域高度设置1，显示10%高度设置0.1</span>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
         <el-button type="primary" @click="addSaveHandler">确 定</el-button>
         <el-button @click="visibleCloseHandler">取 消</el-button>
        </span>
    </el-dialog>
  </basic-container>
</template>

<script>
import basicOption from "@/util/basic-option";
import {addSave, delData, editSave,  getAllData} from "@/api/homeConfig";
import func from "@/util/func";

export default {
  name: "homeConfig",
  data() {
    return {
      loading: false,
      data: [],
      option: {
        ...basicOption,
        addBtn: false,
        editBtn: false,
        delBtn: false,
        calcHeight: -60,
        column: [
          {
            label: '排序',
            prop: 'orderNum',
          },
          {
            label: '组件',
            prop: 'module',
          },
          {
            label: '标题',
            prop: 'title',
          },
          {
            label: '图标',
            prop: 'icon',
          },
          {
            label: '占据列数',
            prop: 'num'
          },
          {
            label: '高度占比',
            prop: 'ratio',
          },
        ]
      },
      dialogTitle: '',
      form: {
        orderNum:1,
        module: "",
        title: "",
        num:24,
        icon: "",
        ratio:1.00
      },
      rules: {
        module: [
          {required: true, message: '请选择组件', trigger: 'blur'},
        ],
        num:[
          {required: true, message: '请输入占据列数', trigger: 'blur'},
        ],
        ratio:[
          {required: true, message: '请输入高度占比', trigger: 'blur'},
        ]
      },
      dic:[],
      visible: false,
      selectList: [],
      lastIndex: null
    }
  },
  created() {
    this.getList();
  },
  methods: {
    getList() {
      getAllData().then(res => {
        const data = res.data.data;
        this.data = data;
        this.loading = false;

        //components下的组件，value值为组件名称
        const dic=[{
          label:'待办流程任务',
          value:'UndoTaskPortlet'
        },{
          label:'待办事项',
          value:'taskPortlet'
        },{
          label:'test',
          value:'test'
        }];
        dic.forEach(dicItem => {
          data.forEach(item => {
            if (dicItem.value == item.module) {
              dicItem.disabled=true;
            }
          })
        })
        this.dic=dic
      });
    },

    // 表格刷新
    handleRefresh() {
      this.getList();
    },

    // 表格多选
    selectChange(row) {
      this.selectList = row;
    },

    // 行单选
    rowClickHandler(row) {
      func.rowClickHandler(
        row,
        this.$refs.crud,
        this.lastIndex,
        (newIndex) => {
          this.lastIndex = newIndex;
        },
        () => {
          this.selectList = [];
        }
      );
    },

    // 创建按钮
    addClickHandler() {
      this.visible = true;
      this.form.orderNum=this.data.length+1;
      this.dialogTitle = 'add';
    },

    // 编辑按钮
    editClickHandler(row) {
      this.visible = true;
      this.dialogTitle = 'edit';
      this.form = {...row};
    },

    // 删除
    delClickHandler() {
      if (this.selectList.length <= 0) {
        this.$message.error('请至少选择一条数据！');
        return;
      }
      this.$confirm('您确定要删除所选择的数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.loading = true;
        delData(this.selectList).then(res => {
          if (res.data.code === 200) {
            this.$message.success(res.data.obj);
            this.getList();
          }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },

    // 行单个删除
    delRowClickHandler(row) {
      this.$confirm('您确定要删除所选择的数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.loading = true;
        delData({oid:row.oid}).then(res => {
          if (res.data.code === 200) {
            this.$message.success(res.data.obj);
            this.getList();
          }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },

    // 关闭对话框
    visibleCloseHandler() {
      const form = {
        orderNum:1,
        module: "",
        title: "",
        num:24,
        icon: "",
        ratio:1
      }
      this.form = form;
      this.visible = false;
      this.$refs.form.clearValidate();
    },

    // 创建或编辑保存
    addSaveHandler() {
      const saveFunction = this.dialogTitle === 'add' ? addSave : editSave;
      this.$refs.form.validate((valid) => {
        if (valid) {
          saveFunction(this.form).then(res => {
            if (res.data.code === 200) {
              this.$message.success(res.data.msg);
              this.loading = true;
              this.getList();
              this.visible = false;
            } else {
              this.$message.error(res.data.msg);
            }
          })
        } else {
          return false;
        }
      });
    },
  }
}
</script>

<style  lang="scss" scoped>
::v-deep {
  .el-scrollbar__wrap {
    overflow: auto !important;
  }

}
</style>
